(cli-debug-info)=

(tmuxp-debug-info)=

# tmuxp debug-info

Use to collect all relevant information for submitting an issue to
the project.

```console

$ tmuxp debug-info
--------------------------
environment:
    system: Linux
    arch: x86_64
...

```

## Reference

```{eval-rst}
.. click:: tmuxp.cli.debug_info:command_debug_info
    :prog: tmuxp debug-info
    :commands: debug-info
    :nested: full
```
